#!/bin/env python3

import json
import subprocess
from typing import Any, List

hyprctl_output = subprocess.check_output(["hyprctl", "monitors", "-j"])
monitors: List[Any] = json.loads(hyprctl_output)

monitors.sort(key=lambda x: x["x"])


def split(a, n):
    k, m = divmod(len(a), n)
    return (a[i * k + min(i, m) : (i + 1) * k + min(i + 1, m)] for i in range(n))


workspaces = list(range(1, 10 + 1))
split_workspaces = list(split(workspaces, len(monitors)))

for i, monitor in enumerate(monitors):
    # Pin workspaces
    workspaces = split_workspaces[i]
    for j, workspace in enumerate(workspaces):
        subprocess.check_call(
            [
                "hyprctl",
                "keyword",
                "workspace",
                f"{str(workspace)},monitor:{str(monitor['name'])}{',default:true' if j == 0 else ''}",
            ]
        )
        subprocess.check_call(
            [
                "hyprctl",
                "dispatch",
                "moveworkspacetomonitor",
                f"{str(workspace)} {str(monitor['id'])}",
            ]
        )

# Switch to default workspace
subprocess.check_call(
    [
        "hyprctl",
        "dispatch",
        "workspace",
        str(1),
    ]
)
