#!/bin/env python3

# Maps the tablet to the current focused monitor
# using open tablet driver (make sure service is running!)

import json
import subprocess
import sys

if len(sys.argv) != 2:
    print("Supply the tablet name as first argument! (Eg. Wacom CTL-4100)")
    exit(1)

tablet = sys.argv[1]


def map_to_focus():
    monitors = subprocess.check_output(["hyprctl", "-j", "monitors"])
    monitors = json.loads(monitors)
    try:
        monitor = next(iter([x for x in monitors if x["focused"]]))
    except StopIteration:
        return
    try:
        subprocess.check_call(
            [
                "otd",
                "setdisplayarea",
                tablet,
                str(monitor["width"]),
                str(monitor["height"]),
                str(monitor["x"] + monitor["width"] / 2),
                str(monitor["y"] + monitor["height"] / 2),
            ],
            stdout=subprocess.DEVNULL,
        )
    except subprocess.CalledProcessError:
        print("otd command failed. Is Opentabletdriver running?")
